<?php
class ControllerModuleShowcase extends Controller {
	protected function index() {
		$this->data['template'] = $this->config->get('config_template');
		$this->language->load('module/showcase');
     	$this->data['heading_title'] = $this->language->get('heading_title');
		$this->data['text_more'] = $this->language->get('text_more');
		$this->data['button_add_to_cart'] = $this->language->get('button_add_to_cart');
		$this->load->model('fido/showcase');
		$this->load->model('catalog/product');
		$this->load->model('catalog/review');
		$this->load->model('tool/seo_url');
		$this->load->model('tool/image');
		$this->data['width'] = $this->config->get('config_image_product_width') + 20;
		$this->data['height'] = $this->config->get('config_image_product_height') + 20;
		$this->data['showcase_timer'] = (int)$this->config->get('showcase_timer');
		$this->data['products'] = array();
		if ($this->config->get('showcase_products') == 'all') {
			$results = $this->model_fido_showcase->getProducts();
		} elseif ($this->config->get('showcase_products') == 'featured') {
			$results = $this->model_fido_showcase->getFeatured();
		} elseif ($this->config->get('showcase_products') == 'special') {
			$results = $this->model_fido_showcase->getSpecials();
		}
		if ($results) {
			foreach ($results as $result) {
				if ($result['image']) {
					$image = $result['image'];
				} else {
					$image = 'no_image.jpg';
				}
				$rating = $this->model_catalog_review->getAverageRating($result['product_id']);	
				$special = FALSE;
				$discount = $this->model_catalog_product->getProductDiscount($result['product_id']);
				if ($discount) {
					$price = $this->currency->format($this->tax->calculate($discount, $result['tax_class_id'], $this->config->get('config_tax')));
				} else {
					$price = $this->currency->format($this->tax->calculate($result['price'], $result['tax_class_id'], $this->config->get('config_tax')));
					$special = $this->model_catalog_product->getProductSpecial($result['product_id']);
					if ($special) {
						$special = $this->currency->format($this->tax->calculate($special, $result['tax_class_id'], $this->config->get('config_tax')));
					}						
				}
				$options = $this->model_catalog_product->getProductOptions($result['product_id']);

				if ($options) {
					$add = $this->model_tool_seo_url->rewrite(HTTP_SERVER . 'index.php?route=product/product&product_id=' . $result['product_id']);
				} else {
					$add = HTTPS_SERVER . 'index.php?route=checkout/cart&product_id=' . $result['product_id'];
				}

				$this->data['products'][] = array(
					'product_id'   => $result['product_id'],
					'name'         => $result['name'],
					'description'  => substr(html_entity_decode($result['description']), 0, $this->config->get('showcase_num_chars')),
					'model'        => $result['model'],
					'rating'       => $rating,
					'stars'        => sprintf($this->language->get('text_stars'), $rating),
					'price'        => $price,
					'options'      => $options,
					'special'      => $special,
					'popup'        => $this->model_tool_image->resize($image, $this->config->get('config_image_popup_width'), $this->config->get('config_image_popup_height')),
					'thumb'        => $this->model_tool_image->resize($image, $this->config->get('config_image_product_width'), $this->config->get('config_image_product_height')),
					'href'         => $this->model_tool_seo_url->rewrite(HTTP_SERVER . 'index.php?route=product/product&product_id=' . $result['product_id']),
					'add'          => $add
				);
			}
		}
		if (!$this->config->get('config_customer_price')) {
			$this->data['display_price'] = TRUE;
		} elseif ($this->customer->isLogged()) {
			$this->data['display_price'] = TRUE;
		} else {
			$this->data['display_price'] = FALSE;
		}
		$this->id = 'showcase';
		if ($this->config->get('showcase_position') == 'home') {
			if (file_exists(DIR_TEMPLATE . $this->config->get('config_template') . '/template/module/showcase_home.tpl')) {
				$this->template = $this->config->get('config_template') . '/template/module/showcase_home.tpl';
			} else {
				$this->template = 'default/template/module/showcase_home.tpl';
			}
		} else {
			if (file_exists(DIR_TEMPLATE . $this->config->get('config_template') . '/template/module/showcase.tpl')) {
				$this->template = $this->config->get('config_template') . '/template/module/showcase.tpl';
			} else {
				$this->template = 'default/template/module/showcase.tpl';
			}
		}
		$this->render();
	}
}
?>
